@@ -659,6 +659,34 @@ int ModFunction::calculate(MathStructure &mstruct, const MathStructure &vargs, c
 	FR_FUNCTION_2(mod)
 }
 
+ParallelFunction::ParallelFunction() : MathFunction("parallel", 2, -1) {}
+int ParallelFunction::calculate(MathStructure &mstruct, const MathStructure &vargs, const EvaluationOptions &eo) {
+	mstruct = vargs;
+	for(size_t i = 0; i < mstruct.size(); i++) {
+		if(!mstruct[i].representsNonZero(true)) mstruct[i].eval(eo);
+		if(mstruct[i].representsZero(true)) {
+			mstruct = vargs;
+			mstruct.eval(eo);
+			for(size_t i2 = 0; i2 < mstruct.size(); i2++) {
+				if((i2 > i && !mstruct[i2].representsNonZero(true)) || (i2 < mstruct.size() - 1 && !mstruct[i2].isUnitCompatible(mstruct[i2 + 1]))) {
+					return 0;
+				}
+			}
+			mstruct.setToChild(i + 1);
+			return 1;
+		}
+		mstruct[i].inverse();
+	}
+	if(mstruct.size() == 0) {
+		mstruct.clear();
+	} else {
+		if(mstruct.size() == 1) mstruct.setToChild(1);
+		else mstruct.setType(STRUCT_ADDITION);
+		mstruct.inverse();
+	}
+	return 1;
+}
+
 BernoulliFunction::BernoulliFunction() : MathFunction("bernoulli", 1, 2) {
 	setArgumentDefinition(1, new IntegerArgument("", ARGUMENT_MIN_MAX_NONNEGATIVE));
 	setDefaultValue(2, "0");
@@ -1284,6 +1312,12 @@ int ImFunction::calculate(MathStructure &mstruct, const MathStructure &vargs, co
 		mstruct *= nr_minus_i;
 		return 1;
 	}
+	if(has_predominately_negative_sign(mstruct)) {
+		negate_struct(mstruct);
+		mstruct.transform(this);
+		mstruct.negate();
+		return 1;
+	}
 	return -1;
 }
 bool ImFunction::representsPositive(const MathStructure&, bool) const {return false;}
@@ -1409,6 +1443,12 @@ int ReFunction::calculate(MathStructure &mstruct, const MathStructure &vargs, co
 			return 1;
 		}
 	}
+	if(has_predominately_negative_sign(mstruct)) {
+		negate_struct(mstruct);
+		mstruct.transform(this);
+		mstruct.negate();
+		return 1;
+	}
 	return -1;
 }
 bool ReFunction::representsPositive(const MathStructure &vargs, bool allow_units) const {return vargs.size() == 1 && vargs[0].representsPositive(allow_units);}
