@@ -13,6 +13,7 @@
 #define BUILTIN_FUNCTIONS_H
 
 #include <libqalculate/Function.h>
+#include <libqalculate/MathStructure.h>
 #include <libqalculate/includes.h>
 
 #define DECLARE_BUILTIN_FUNCTION(x, i)	class x : public MathFunction { \
@@ -54,6 +55,18 @@
 						bool representsReal(const MathStructure&, bool) const;\
 						bool representsInteger(const MathStructure&, bool) const;\
 						bool representsNonNegative(const MathStructure&, bool) const;\
+						bool representsNonMatrix(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsNonMatrix()) return false;\
+							}\
+							return true;\
+						}\
+						bool representsScalar(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsScalar()) return false;\
+							}\
+							return true;\
+						}\
 						int id() const {return i;}\
 					};
 
@@ -77,6 +90,18 @@
 						bool representsEven(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsOdd(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsUndefined(const MathStructure &vargs) const;\
+						bool representsNonMatrix(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsNonMatrix()) return false;\
+							}\
+							return true;\
+						}\
+						bool representsScalar(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsScalar()) return false;\
+							}\
+							return true;\
+						}\
 						int id() const {return i;}\
 					};
 
@@ -89,6 +114,18 @@
 						bool representsNumber(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsReal(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsNonComplex(const MathStructure &vargs, bool allow_units = false) const;\
+						bool representsNonMatrix(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsNonMatrix()) return false;\
+							}\
+							return true;\
+						}\
+						bool representsScalar(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsScalar()) return false;\
+							}\
+							return true;\
+						}\
 						int id() const {return i;}\
 					};
 
@@ -103,6 +140,18 @@
 						bool representsNonComplex(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsComplex(const MathStructure &vargs, bool allow_units = false) const;\
 						bool representsNonZero(const MathStructure &vargs, bool allow_units = false) const;\
+						bool representsNonMatrix(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsNonMatrix()) return false;\
+							}\
+							return true;\
+						}\
+						bool representsScalar(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsScalar()) return false;\
+							}\
+							return true;\
+						}\
 						int id() const {return i;}\
 					};
 
@@ -113,6 +162,18 @@
 						x(const x *function) {set(function);} \
 						ExpressionItem *copy() const {return new x(this);} \
 						bool representsNumber(const MathStructure &vargs, bool allow_units = false) const;\
+						bool representsNonMatrix(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsNonMatrix()) return false;\
+							}\
+							return true;\
+						}\
+						bool representsScalar(const MathStructure &vargs) const {\
+							for(size_t i = 0; i < vargs.size(); i++) {\
+								if(!vargs[i].representsScalar()) return false;\
+							}\
+							return true;\
+						}\
 						int id() const {return i;}\
 					};
 
@@ -224,6 +285,7 @@ enum {
 	FUNCTION_ID_FRAC = 1733,
 	FUNCTION_ID_REM = 1734,
 	FUNCTION_ID_MOD = 1735,
+	FUNCTION_ID_PARALLEL = 1736,
 	FUNCTION_ID_BERNOULLI = 1740,
 	FUNCTION_ID_TOTIENT = 1745,
 	FUNCTION_ID_RE = 1750,
@@ -460,6 +522,7 @@ DECLARE_BUILTIN_FUNCTION(RemFunction, FUNCTION_ID_REM)
 DECLARE_BUILTIN_FUNCTION(ModFunction, FUNCTION_ID_MOD)
 DECLARE_BUILTIN_FUNCTION(BernoulliFunction, FUNCTION_ID_BERNOULLI)
 DECLARE_BUILTIN_FUNCTION(TotientFunction, FUNCTION_ID_TOTIENT)
+DECLARE_BUILTIN_FUNCTION(ParallelFunction, FUNCTION_ID_PARALLEL)
 
 DECLARE_BUILTIN_FUNCTION(BinFunction, FUNCTION_ID_BIN)
 DECLARE_BUILTIN_FUNCTION(OctFunction, FUNCTION_ID_OCT)
@@ -475,10 +538,10 @@ DECLARE_BUILTIN_FUNCTION(IEEE754FloatComponentsFunction, FUNCTION_ID_IEEE754_FLO
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatValueFunction, FUNCTION_ID_IEEE754_FLOAT_VALUE)
 DECLARE_BUILTIN_FUNCTION(IEEE754FloatErrorFunction, FUNCTION_ID_IEEE754_FLOAT_ERROR)
 
-DECLARE_BUILTIN_FUNCTION(IsNumberFunction, FUNCTION_ID_IS_NUMBER)
-DECLARE_BUILTIN_FUNCTION(IsRealFunction, FUNCTION_ID_IS_REAL)
-DECLARE_BUILTIN_FUNCTION(IsRationalFunction, FUNCTION_ID_IS_RATIONAL)
-DECLARE_BUILTIN_FUNCTION(IsIntegerFunction, FUNCTION_ID_IS_INTEGER)
+DECLARE_BUILTIN_FUNCTION_B(IsNumberFunction, FUNCTION_ID_IS_NUMBER)
+DECLARE_BUILTIN_FUNCTION_B(IsRealFunction, FUNCTION_ID_IS_REAL)
+DECLARE_BUILTIN_FUNCTION_B(IsRationalFunction, FUNCTION_ID_IS_RATIONAL)
+DECLARE_BUILTIN_FUNCTION_B(IsIntegerFunction, FUNCTION_ID_IS_INTEGER)
 DECLARE_BUILTIN_FUNCTION_B(OddFunction, FUNCTION_ID_ODD)
 DECLARE_BUILTIN_FUNCTION_B(EvenFunction, FUNCTION_ID_EVEN)
 
