@@ -14,6 +14,7 @@
 #include "Calculator.h"
 #include "util.h"
 #include "MathStructure.h"
+#include "MathStructure-support.h"
 
 #include <locale.h>
 #include <unistd.h>
@@ -65,7 +66,11 @@ bool Calculator::canPlot() {
 	return pclose(pipe) == 0;
 #	endif
 #else
+#	ifdef HAVE_BYO_GNUPLOT
+	return true;
+#	else
 	return false;
+#	endif
 #endif
 }
 
@@ -168,10 +173,75 @@ MathStructure Calculator::expressionToPlotVector(string expression, const MathSt
 	return y_vector;
 }
 
+#ifdef HAVE_GNUPLOT_CALL
+bool Calculator::invokeGnuplot(string commands, string commandline_extra, bool persistent) {
+	FILE *pipe = NULL;
+	if(!b_gnuplot_open || !gnuplot_pipe || persistent || commandline_extra != gnuplot_cmdline) {
+		if(!persistent) {
+			closeGnuplot();
+		}
+		string commandline = "gnuplot";
+		if(persistent) {
+			commandline += " -persist";
+		}
+		commandline += commandline_extra;
+#ifdef _WIN32
+		commandline += " - 2>nul";
+		pipe = _popen(commandline.c_str(), "w");
+#else
+		commandline += " - 2>/dev/null";
+		pipe = popen(commandline.c_str(), "w");
+#endif
+		if(!pipe) {
+			error(true, _("Failed to invoke gnuplot. Make sure that you have gnuplot installed in your path."), NULL);
+			return false;
+		}
+		if(!persistent && pipe) {
+			gnuplot_pipe = pipe;
+			b_gnuplot_open = true;
+			gnuplot_cmdline = commandline_extra;
+		}
+	} else {
+		pipe = gnuplot_pipe;
+	}
+	if(!pipe) {
+		return false;
+	}
+	if(!persistent) {
+		fputs("clear\n", pipe);
+		fputs("reset\n", pipe);
+	}
+	fputs(commands.c_str(), pipe);
+	fflush(pipe);
+	if(persistent) {
+		return pclose(pipe) == 0;
+	}
+	return true;
+}
+#else
+#	ifdef HAVE_BYO_GNUPLOT
+bool qalc_invoke_gnuplot(vector<std::pair<string, string>>, string, string, bool);
+string qalc_gnuplot_data_dir();
+#	else
+bool Calculator::invokeGnuplot(string, string, bool) {
+	return false;
+}
+#	endif
+#endif
+
 bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure> &y_vectors, const vector<MathStructure> &x_vectors, vector<PlotDataParameters*> &pdps, bool persistent, int msecs) {
 
-	string homedir = getLocalTmpDir();
+	string homedir;
+#ifdef HAVE_GNUPLOT_CALL
+	homedir = getLocalTmpDir();
 	recursiveMakeDir(homedir);
+#else
+#	ifdef HAVE_BYO_GNUPLOT
+	homedir = qalc_gnuplot_data_dir();
+#	else
+	return false;
+#	endif
+#endif
 
 	string commandline_extra;
 	string title;
@@ -294,8 +364,38 @@ bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure>
 		plot += title;
 		plot += "\"\n";
 	}
-	if(!param->y_label.empty()) {
+
+	vector<MathStructure> munit;
+	string sunit;
+	if(!param->y_label.empty()) sunit = "0";
+	for(size_t serie = 0; serie < y_vectors.size(); serie++) {
+		if(y_vectors[serie].isUndefined()) {
+			munit.push_back(m_undefined);
+		} else {
+			munit.push_back(m_zero);
+			if(y_vectors[serie].size() > 0 && !y_vectors[serie][0].isNumber()) {
+				if(is_unit_multiexp(y_vectors[serie][0])) {
+					munit[serie] = y_vectors[serie][0];
+				} else if(y_vectors[serie][0].isMultiplication() && y_vectors[serie][0].size() >= 2 && y_vectors[serie][0][0].isNumber()) {
+					munit[serie] = y_vectors[serie][0];
+					munit[serie].delChild(1, true);
+					if(!is_unit_multiexp(munit[serie])) munit[serie].clear();
+				}
+			}
+			if(sunit != "0") {
+				if(munit[serie].isZero()) {
+					sunit = "0";
+				} else {
+					string str = munit[serie].print();
+					if(sunit.empty()) sunit = str;
+					else if(str != sunit) sunit = "0";
+				}
+			}
+		}
+	}
+	if(!param->y_label.empty() || (!sunit.empty() && sunit != "0")) {
 		string title = param->y_label;
+		if(title.empty()) title = sunit;
 		gsub("\"", "\\\"", title);
 		plot += "set ylabel \"";
 		plot += title;
@@ -430,37 +530,69 @@ bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure>
 	po.interval_display = INTERVAL_DISPLAY_MIDPOINT;
 	po.decimalpoint_sign = ".";
 	po.comma_sign = ",";
+#ifndef HAVE_GNUPLOT_CALL
+	vector<std::pair<string, string>> data_files;
+#endif
+	MathStructure m, mprev;
 	for(size_t serie = 0; serie < y_vectors.size(); serie++) {
 		if(!y_vectors[serie].isUndefined()) {
 			string filename = "gnuplot_data";
 			filename += i2s(serie + 1);
+#ifdef HAVE_GNUPLOT_CALL
 			string filepath = buildPath(homedir, filename);
 			FILE *fdata = fopen(filepath.c_str(), "w+");
 			if(!fdata) {
 				error(true, _("Could not create temporary file %s"), filepath.c_str(), NULL);
 				return false;
 			}
+#else
+			filename = buildPath(homedir, filename);
+#endif
 			plot_data = "";
 			int non_numerical = 0, non_real = 0;
-			//string str = "";
 			if(msecs > 0) startControl(msecs);
 			ComparisonResult ct1 = COMPARISON_RESULT_EQUAL, ct2 = COMPARISON_RESULT_EQUAL;
 			size_t last_index = string::npos, last_index2 = string::npos;
 			bool check_continuous = pdps[serie]->test_continuous && (pdps[serie]->style == PLOT_STYLE_LINES || pdps[serie]->style == PLOT_STYLE_POINTS_LINES);
 			bool prev_failed = false;
+			const MathStructure *yprev = NULL;
 			for(size_t i = 1; i <= y_vectors[serie].countChildren(); i++) {
 				ComparisonResult ct = COMPARISON_RESULT_UNKNOWN;
 				bool invalid_nr = false, b_imagzero_x = false, b_imagzero_y = false;
-				if(!y_vectors[serie].getChild(i)->isNumber()) {
+				const MathStructure *yvalue = y_vectors[serie].getChild(i);
+				if(!yvalue->isNumber() && !munit[serie].isZero()) {
+					if(yvalue->isMultiplication() && yvalue->size() >= 2 && yvalue->getChild(1)->isNumber()) {
+						bool b = false;
+						if(yvalue->size() == 2 && yvalue->getChild(2)->equals(munit[serie])) {
+							b = true;
+						} else if(yvalue->size() > 2 && munit[serie].isMultiplication() && munit[serie].size() == yvalue->size() - 1) {
+							b = true;
+							for(size_t i2 = 0; i2 < munit[serie].size(); i2++) {
+								if(!yvalue->getChild(i2 + 2)->equals(munit[serie][i2])) {
+									b = false;
+									break;
+								}
+							}
+						}
+						if(b) {
+							m = *yvalue->getChild(1);
+							yvalue = &m;
+						}
+					} else if(yvalue->equals(munit[serie])) {
+						m.set(1, 1, 0);
+						yvalue = &m;
+					}
+				}
+				if(!yvalue->isNumber()) {
 					invalid_nr = true;
 					non_numerical++;
-					//if(non_numerical == 1) str = y_vectors[serie].getChild(i)->print(po);
-				} else if(!y_vectors[serie].getChild(i)->number().isReal()) {
-					b_imagzero_y = testComplexZero(&y_vectors[serie].getChild(i)->number(), y_vectors[serie].getChild(i)->number().internalImaginary());
+					//if(non_numerical == 1) str = yvalue->print(po);
+				} else if(!yvalue->number().isReal()) {
+					b_imagzero_y = testComplexZero(&yvalue->number(), yvalue->number().internalImaginary());
 					if(!b_imagzero_y) {
 						invalid_nr = true;
 						non_real++;
-						//if(non_numerical + non_real == 1) str = y_vectors[serie].getChild(i)->print(po);
+						//if(non_numerical + non_real == 1) str = yvalue->print(po);
 					}
 				}
 				if(serie < x_vectors.size() && !x_vectors[serie].isUndefined() && x_vectors[serie].countChildren() == y_vectors[serie].countChildren()) {
@@ -485,13 +617,16 @@ bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure>
 				if(!invalid_nr) {
 					if(check_continuous && !prev_failed) {
 						if(i == 1 || ct2 == COMPARISON_RESULT_UNKNOWN) ct = COMPARISON_RESULT_EQUAL;
-						else ct = y_vectors[serie].getChild(i - 1)->number().compare(y_vectors[serie].getChild(i)->number());
+						else ct = yprev->number().compare(yvalue->number());
 						if((ct == COMPARISON_RESULT_GREATER || ct == COMPARISON_RESULT_LESS) && (ct1 == COMPARISON_RESULT_GREATER || ct1 == COMPARISON_RESULT_LESS) && (ct2 == COMPARISON_RESULT_GREATER || ct2 == COMPARISON_RESULT_LESS) && ct1 != ct2 && ct != ct2) {
-							if(last_index2 != string::npos) plot_data.insert(last_index2 + 1, "  \n");
+							if(last_index2 != string::npos) {
+								plot_data.insert(last_index2 + 1, "  \n");
+								last_index += 3;
+							}
 						}
 					}
-					if(b_imagzero_x) plot_data += y_vectors[serie].getChild(i)->number().realPart().print(po);
-					else plot_data += y_vectors[serie].getChild(i)->print(po);
+					if(b_imagzero_x) plot_data += yvalue->number().realPart().print(po);
+					else plot_data += yvalue->print(po);
 					plot_data += "\n";
 					prev_failed = false;
 				} else if(!prev_failed) {
@@ -499,12 +634,21 @@ bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure>
 					plot_data += "  \n";
 					prev_failed = true;
 				}
+				if(yprev == &m) {
+					mprev = m;
+					yprev = &mprev;
+					m.clear();
+				} else {
+					yprev = yvalue;
+				}
 				last_index2 = last_index;
 				last_index = plot_data.length() - 1;
 				ct1 = ct2;
 				ct2 = ct;
 				if(aborted()) {
+#ifdef HAVE_GNUPLOT_CALL
 					fclose(fdata);
+#endif
 					if(msecs > 0) {
 						error(true, _("It took too long to generate the plot data."), NULL);
 						stopControl();
@@ -513,77 +657,24 @@ bool Calculator::plotVectors(PlotParameters *param, const vector<MathStructure>
 				}
 			}
 			if(msecs > 0) stopControl();
-			/*if(non_numerical > 0 || non_real > 0) {
-				string stitle;
-				if(serie < pdps.size() && !pdps[serie]->title.empty()) {
-					stitle = pdps[serie]->title.c_str();
-				} else {
-					stitle = i2s(serie).c_str();
-				}
-				if(non_numerical > 0) {
-					error(true, _("Series %s contains non-numerical data (\"%s\" first of %s) which can not be properly plotted."), stitle.c_str(), str.c_str(), i2s(non_numerical).c_str(), NULL);
-				} else {
-					error(true, _("Series %s contains non-real data (\"%s\" first of %s) which can not be properly plotted."), stitle.c_str(), str.c_str(), i2s(non_real).c_str(), NULL);
-				}
-			}*/
+#ifdef HAVE_GNUPLOT_CALL
 			fputs(plot_data.c_str(), fdata);
 			fflush(fdata);
 			fclose(fdata);
+#else
+			data_files.push_back(std::make_pair(filename, plot_data));
+#endif
 		}
 	}
-
-	return invokeGnuplot(plot, commandline_extra, persistent);
-}
 #ifdef HAVE_GNUPLOT_CALL
-bool Calculator::invokeGnuplot(string commands, string commandline_extra, bool persistent) {
-	FILE *pipe = NULL;
-	if(!b_gnuplot_open || !gnuplot_pipe || persistent || commandline_extra != gnuplot_cmdline) {
-		if(!persistent) {
-			closeGnuplot();
-		}
-		string commandline = "gnuplot";
-		if(persistent) {
-			commandline += " -persist";
-		}
-		commandline += commandline_extra;
-#ifdef _WIN32
-		commandline += " - 2>nul";
-		pipe = _popen(commandline.c_str(), "w");
+	return invokeGnuplot(plot, commandline_extra, persistent);
 #else
-		commandline += " - 2>/dev/null";
-		pipe = popen(commandline.c_str(), "w");
-#endif
-		if(!pipe) {
-			error(true, _("Failed to invoke gnuplot. Make sure that you have gnuplot installed in your path."), NULL);
-			return false;
-		}
-		if(!persistent && pipe) {
-			gnuplot_pipe = pipe;
-			b_gnuplot_open = true;
-			gnuplot_cmdline = commandline_extra;
-		}
-	} else {
-		pipe = gnuplot_pipe;
-	}
-	if(!pipe) {
-		return false;
-	}
-	if(!persistent) {
-		fputs("clear\n", pipe);
-		fputs("reset\n", pipe);
-	}
-	fputs(commands.c_str(), pipe);
-	fflush(pipe);
-	if(persistent) {
-		return pclose(pipe) == 0;
-	}
-	return true;
-}
-#else
-bool Calculator::invokeGnuplot(string, string, bool) {
+#	ifdef HAVE_BYO_GNUPLOT
+	return qalc_invoke_gnuplot(data_files, plot, commandline_extra, persistent);
+#	endif
 	return false;
-}
 #endif
+}
 bool Calculator::closeGnuplot() {
 #ifdef HAVE_GNUPLOT_CALL
 	if(gnuplot_pipe) {
@@ -600,10 +691,13 @@ bool Calculator::closeGnuplot() {
 	b_gnuplot_open = false;
 	return true;
 #else
+#	ifdef HAVE_BYO_GNUPLOT
+	return true;
+#	else
 	return false;
+#	endif
 #endif
 }
 bool Calculator::gnuplotOpen() {
 	return b_gnuplot_open && gnuplot_pipe;
 }
-
