@@ -855,6 +855,7 @@ MathStructure MathStructure::generateVector(MathStructure x_mstruct, const MathS
 	MathStructure step(max);
 	step.calculateSubtract(min, eo);
 	step.calculateDivide(steps - 1, eo);
+	step.eval(eo);
 	if(!step.isNumber() || step.number().isNegative()) {
 		CALCULATOR->error(true, _("The selected min and max do not result in a positive, finite number of data points"), NULL);
 		return y_vector;
@@ -891,6 +892,7 @@ MathStructure MathStructure::generateVector(MathStructure x_mstruct, const MathS
 		MathStructure mtest(max);
 		mtest.calculateSubtract(min, eo);
 		if(!step.isZero()) mtest.calculateDivide(step, eo);
+		mtest.eval(eo);
 		if(step.isZero() || !mtest.isNumber() || mtest.number().isNegative()) {
 			CALCULATOR->error(true, _("The selected min, max and step size do not result in a positive, finite number of data points"), NULL);
 			return y_vector;
