@@ -130,6 +130,10 @@ bool sync_approximate_units(MathStructure &m, const EvaluationOptions &feo, std:
 void fix_to_struct(MathStructure &m);
 int has_information_unit(const MathStructure &m, bool top = true);
 bool calculate_userfunctions(MathStructure &m, const MathStructure &x_mstruct, const EvaluationOptions &eo);
+bool comparison_is_not_equal(ComparisonResult cr);
+bool comparison_is_equal_or_less(ComparisonResult cr);
+bool comparison_is_equal_or_greater(ComparisonResult cr);
+bool comparison_might_be_equal(ComparisonResult cr);
 
 void print_dual(const MathStructure &mresult, const std::string &original_expression, const MathStructure &mparse, MathStructure &mexact, std::string &result_str, std::vector<std::string> &results_v, PrintOptions &po, const EvaluationOptions &evalops, AutomaticFractionFormat auto_frac, AutomaticApproximation auto_approx, bool cplx_angle = false, bool *exact_cmp = NULL, bool b_parsed = true, bool format = false, int colorize = 0, int tagtype = TAG_TYPE_HTML, int max_length = -1);
 void calculate_dual_exact(MathStructure &mstruct_exact, MathStructure *mstruct, const std::string &original_expression, const MathStructure *parsed_mstruct, EvaluationOptions &evalops, AutomaticApproximation auto_approx, int msecs = 0, int max_size = 10);
