@@ -12,6 +12,10 @@
 #  include <libintl.h>
 #  undef _
 #  define _(String) dgettext (GETTEXT_PACKAGE, String)
+#  undef _n
+#  define _n(String, String_plural, n) dngettext (GETTEXT_PACKAGE, String, String_plural, n)
+#  undef _c
+#  define _c(Context, String) (strcmp(dgettext (GETTEXT_PACKAGE, Context "\004" String), Context "\004" String) == 0 ? String : dgettext (GETTEXT_PACKAGE, Context "\004" String))
 #  ifdef gettext_noop
 #    define N_(String) gettext_noop (String)
 #  else
@@ -21,9 +25,12 @@
 #  define textdomain(String) (String)
 #  define gettext(String) (String)
 #  define dgettext(Domain,Message) (Message)
+#  define _p(Context,Message) (Message)
 #  define dcgettext(Domain,Message,Type) (Message)
 #  define bindtextdomain(Domain,Directory) (Domain)
 #  define _(String) (String)
+#  define _c(Context, String) (String)
+#  define _n(String, String_plural, n) (String)
 #  define N_(String) (String)
 #endif
 
